@@ -28,14 +28,15 @@
 #include <KServiceGroup>
 
 class AppsModel;
-class ContainmentInterface;
+class MenuEntryEditor;
 
+class QQmlPropertyMap;
 class QTimer;
 
 class AppGroupEntry : public AbstractGroupEntry
 {
     public:
-        AppGroupEntry(KServiceGroup::Ptr group, QAbstractListModel *parentModel,
+        AppGroupEntry(KServiceGroup::Ptr group, AppsModel *parentModel,
             bool flat, int appNameFormat);
 };
 
@@ -65,7 +66,7 @@ class AppsModel : public AbstractModel
 
     Q_PROPERTY(bool flat READ flat WRITE setFlat NOTIFY flatChanged)
     Q_PROPERTY(int appNameFormat READ appNameFormat WRITE setAppNameFormat NOTIFY appNameFormatChanged)
-    Q_PROPERTY(QObject* appletInterface READ appletInterface WRITE setAppletInterface);
+    Q_PROPERTY(QObject* appletInterface READ appletInterface WRITE setAppletInterface NOTIFY appletInterfaceChanged);
 
     public:
         explicit AppsModel(const QString &entryPath = QString(), bool flat = false, QObject *parent = 0);
@@ -85,19 +86,25 @@ class AppsModel : public AbstractModel
         int appNameFormat() const;
         void setAppNameFormat(int format);
 
+        QStringList hiddenEntries() const;
+
         QObject *appletInterface() const;
+
+    public Q_SLOTS:
         void setAppletInterface(QObject *appletInterface);
 
     Q_SIGNALS:
         void refreshing() const;
         void flatChanged() const;
         void appNameFormatChanged() const;
+        void appletInterfaceChanged(QObject *appletInterface) const;
 
     protected Q_SLOTS:
         virtual void refresh();
 
     private Q_SLOTS:
         void checkSycocaChanges(const QStringList &changes);
+        QQmlPropertyMap *appletConfig() const;
 
     protected:
         QList<AbstractEntry *> m_entryList;
@@ -110,7 +117,9 @@ class AppsModel : public AbstractModel
         bool m_flat;
         AppEntry::NameFormat m_appNameFormat;
         bool m_sortNeeded;
-        static ContainmentInterface *m_containmentInterface;
+        QStringList m_hiddenEntries;
+        QObject *m_appletInterface;
+        static MenuEntryEditor *m_menuEntryEditor;
 };
 
 #endif
