@@ -42,12 +42,16 @@
 
 #include "internallibkonq/konq_popupmenu.h"
 #include "internallibkonq/konq_operations.h"
-#include "internallibkonq/konqmimedata.h"
 #include <KAuthorized>
 #include <KBookmarkManager>
 #include <KConfigGroup>
+#include <KFileItemActions>
+#include <KFileItemListProperties>
 #include <KNewFileMenu>
+#include <KIO/DeleteJob>
+#include <KIO/EmptyTrashJob>
 #include <KIO/FileUndoManager>
+#include <KIO/JobUiDelegate>
 #include <KIO/Paste>
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -89,9 +93,10 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
     m_viewAdapter(0),
     m_actionCollection(this),
     m_newMenu(0),
+    m_fileItemActions(0),
     m_usedByContainment(false),
     m_locked(true),
-    m_sortMode(1),
+    m_sortMode(0),
     m_sortDesc(false),
     m_sortDirsFirst(true),
     m_parseDesktopFiles(false),
@@ -106,6 +111,7 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
 
     m_dirModel = new KDirModel(this);
     m_dirModel->setDirLister(dirLister);
+    m_dirModel->setDropsAllowed(KDirModel::DropOnDirectory | KDirModel::DropOnLocalExecutable);
 
     m_selectionModel = new QItemSelectionModel(this, this);
     connect(m_selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
@@ -117,7 +123,7 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
     setFilterCaseSensitivity(Qt::CaseInsensitive);
     setDynamicSortFilter(true);
 
-    sort(m_sortMode - 1, m_sortDesc ? Qt::DescendingOrder : Qt::AscendingOrder);
+    sort(m_sortMode, m_sortDesc ? Qt::DescendingOrder : Qt::AscendingOrder);
 
     setSupportedDragActions(Qt::CopyAction | Qt::MoveAction | Qt::LinkAction);
 
@@ -130,7 +136,12 @@ FolderModel::~FolderModel()
 
 QHash< int, QByteArray > FolderModel::roleNames() const
 {
-    QHash<int, QByteArray> roleNames = m_dirModel->roleNames();
+    return staticRoleNames();
+}
+
+QHash< int, QByteArray > FolderModel::staticRoleNames()
+{
+    QHash<int, QByteArray> roleNames;
     roleNames[Qt::DisplayRole] = "display";
     roleNames[Qt::DecorationRole] = "decoration";
     roleNames[BlankRole] = "blank";
@@ -148,34 +159,40 @@ QString FolderModel::url() const
     return m_url;
 }
 
-void FolderModel::setUrl(const QString& _url)
+void FolderModel::setUrl(const QString& url)
 {
-    QUrl url;
+    QUrl resolvedUrl;
 
-    if (_url.startsWith('~')) {
-        url = QUrl::fromLocalFile(KShell::tildeExpand(_url));
+    if (url.startsWith('~')) {
+        resolvedUrl = QUrl::fromLocalFile(KShell::tildeExpand(url));
     } else {
-        url = QUrl::fromUserInput(_url);
+        resolvedUrl = QUrl::fromUserInput(url);
     }
 
-    if (_url == m_url) {
-        m_dirModel->dirLister()->updateDirectory(url);
+    if (url == m_url) {
+        m_dirModel->dirLister()->updateDirectory(resolvedUrl);
 
         return;
     }
 
     beginResetModel();
-    m_url = _url;
-    m_dirModel->dirLister()->openUrl(url);
+    m_url = url;
+    m_dirModel->dirLister()->openUrl(resolvedUrl);
     clearDragImages();
     endResetModel();
 
     emit urlChanged();
+    emit resolvedUrlChanged();
 
     m_errorString.clear();
     emit errorStringChanged();
 }
 
+QUrl FolderModel::resolvedUrl() const
+{
+    return m_dirModel->dirLister()->url();
+}
+
 QString FolderModel::errorString() const
 {
     return m_errorString;
@@ -191,6 +208,13 @@ void FolderModel::setUsedByContainment(bool used)
     if (m_usedByContainment != used) {
         m_usedByContainment = used;
 
+        QAction *action = m_actionCollection.action("refresh");
+
+        if (action) {
+            action->setText(m_usedByContainment ? i18n("&Refresh Desktop") : i18n("&Refresh View"));
+            action->setIcon(m_usedByContainment ? QIcon::fromTheme("user-desktop") : QIcon::fromTheme("view-refresh"));
+        }
+
         emit usedByContainmentChanged();
     }
 }
@@ -225,12 +249,12 @@ void FolderModel::setSortMode(int mode)
     if (m_sortMode != mode) {
         m_sortMode = mode;
 
-        if (mode == 0 /* Unsorted */) {
+        if (mode == -1 /* Unsorted */) {
             setDynamicSortFilter(false);
         } else {
-            setDynamicSortFilter(true);
             invalidate();
-            sort(m_sortMode - 1, m_sortDesc ? Qt::DescendingOrder : Qt::AscendingOrder);
+            sort(m_sortMode, m_sortDesc ? Qt::DescendingOrder : Qt::AscendingOrder);
+            setDynamicSortFilter(true);
         }
 
         emit sortModeChanged();
@@ -247,9 +271,9 @@ void FolderModel::setSortDesc(bool desc)
     if (m_sortDesc != desc) {
         m_sortDesc = desc;
 
-        if (m_sortMode != 0) {
+        if (m_sortMode != -1 /* Unsorted */) {
             invalidate();
-            sort(m_sortMode - 1, m_sortDesc ? Qt::DescendingOrder : Qt::AscendingOrder);
+            sort(m_sortMode, m_sortDesc ? Qt::DescendingOrder : Qt::AscendingOrder);
         }
 
         emit sortDescChanged();
@@ -266,9 +290,9 @@ void FolderModel::setSortDirsFirst(bool enable)
     if (m_sortDirsFirst != enable) {
         m_sortDirsFirst = enable;
 
-        if (m_sortMode != 0) {
+        if (m_sortMode != -1 /* Unsorted */) {
             invalidate();
-            sort(m_sortMode - 1, m_sortDesc ? Qt::DescendingOrder : Qt::AscendingOrder);
+            sort(m_sortMode, m_sortDesc ? Qt::DescendingOrder : Qt::AscendingOrder);
         }
 
         emit sortDirsFirstChanged();
@@ -463,13 +487,13 @@ void FolderModel::toggleSelected(int row)
     m_selectionModel->select(index(row, 0), QItemSelectionModel::Toggle);
 }
 
-void FolderModel::setRangeSelected(int startRow, int endRow)
+void FolderModel::setRangeSelected(int anchor, int to)
 {
-    if (startRow < 0 || endRow < 0) {
+    if (anchor < 0 || to < 0) {
         return;
     }
 
-    QItemSelection selection(index(startRow, 0), index(endRow, 0));
+    QItemSelection selection(index(anchor, 0), index(to, 0));
     m_selectionModel->select(selection, QItemSelectionModel::ClearAndSelect);
 }
 
@@ -595,8 +619,8 @@ void FolderModel::addDragImage(QDrag *drag, int x, int y)
     foreach (DragImage *image, m_dragImages) {
         if (!image->blank && !image->image.isNull()) {
             pos = image->rect.translated(-offset.x(), -offset.y()).topLeft();
-            image->cursorOffset.setX(pos.x());
-            image->cursorOffset.setY(pos.y());
+            image->cursorOffset.setX(pos.x() - (x - offset.x()));
+            image->cursorOffset.setY(pos.y() - (y - offset.y()));
 
             painter.drawImage(pos, image->image);
         }
@@ -611,8 +635,6 @@ void FolderModel::addDragImage(QDrag *drag, int x, int y)
 
 void FolderModel::dragSelected(int x, int y)
 {
-    //FIXME Don't drag blank ones.
-
     if (!m_viewAdapter || !m_selectionModel->hasSelection()) {
         return;
     }
@@ -660,12 +682,12 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
         return;
     }
 
-    if (m_dragInProgress) {
+    if (m_dragInProgress && row == -1) {
         if (m_locked || mimeData->urls().isEmpty()) {
             return;
         }
 
-        setSortMode(0);
+        setSortMode(-1);
 
         emit move(dropEvent->property("x").toInt(), dropEvent->property("y").toInt(),
             mimeData->urls());
@@ -673,10 +695,12 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
         return;
     }
 
+    QModelIndex idx;
     KFileItem item;
 
     if (row > -1 && row < rowCount()) {
-         item = itemForIndex(index(row, 0));
+         idx = index(row, 0);
+         item = itemForIndex(idx);
     }
 
     if (item.isNull() &&
@@ -696,6 +720,10 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
         return;
     }
 
+    if (idx.isValid() && !(flags(idx) & Qt::ItemIsDropEnabled)) {
+        return;
+    }
+
     QPoint pos;
     pos.setX(dropEvent->property("x").toInt());
     pos.setY(dropEvent->property("y").toInt());
@@ -812,16 +840,16 @@ bool FolderModel::lessThan(const QModelIndex &left, const QModelIndex &right) co
 {
     const KDirModel *dirModel = static_cast<KDirModel*>(sourceModel());
 
-    // When sorting by size, folders are compared using the number of items in them,
-    // so they need to be given precedence over regular files as the comparison criteria is different
     if (m_sortDirsFirst || left.column() == KDirModel::Size) {
         bool leftIsDir = isDir(left, dirModel);
         bool rightIsDir = isDir(right, dirModel);
+
         if (leftIsDir && !rightIsDir) {
-            return (sortOrder() == Qt::AscendingOrder); // folders > files independent of the sorting order
+            return (sortOrder() == Qt::AscendingOrder);
         }
+
         if (!leftIsDir && rightIsDir) {
-            return (sortOrder() == Qt::DescendingOrder); // same here
+            return (sortOrder() == Qt::DescendingOrder);
         }
     }
 
@@ -831,42 +859,42 @@ bool FolderModel::lessThan(const QModelIndex &left, const QModelIndex &right) co
     int result = 0;
 
     switch (column) {
-      case KDirModel::Name:
-            // fall through to the naturalCompare call
-            break;
-        case KDirModel::ModifiedTime: {
-            const QDateTime leftTime = leftItem.time(KFileItem::ModificationTime);
-            const QDateTime rightTime = rightItem.time(KFileItem::ModificationTime);
-            if (leftTime < rightTime)
-                result = -1;
-            else if (leftTime > rightTime)
-                result = +1;
-            break;
-            }
         case KDirModel::Size: {
-            if (isDir(left, dirModel) && isDir(right, dirModel)) {
-                const int leftChildCount = dirModel->data(left, KDirModel::ChildCountRole).toInt();
-                const int rightChildCount = dirModel->data(right, KDirModel::ChildCountRole).toInt();
-                if (leftChildCount < rightChildCount)
-                    result = -1;
-                else if (leftChildCount > rightChildCount)
-                    result = +1;
-            } else {
-                const KIO::filesize_t leftSize = leftItem.size();
-                const KIO::filesize_t rightSize = rightItem.size();
-                if (leftSize < rightSize)
-                    result = -1;
-                else if (leftSize > rightSize)
-                    result = +1;
+                if (isDir(left, dirModel) && isDir(right, dirModel)) {
+                    const int leftChildCount = dirModel->data(left, KDirModel::ChildCountRole).toInt();
+                    const int rightChildCount = dirModel->data(right, KDirModel::ChildCountRole).toInt();
+                    if (leftChildCount < rightChildCount)
+                        result = -1;
+                    else if (leftChildCount > rightChildCount)
+                        result = +1;
+                } else {
+                    const KIO::filesize_t leftSize = leftItem.size();
+                    const KIO::filesize_t rightSize = rightItem.size();
+                    if (leftSize < rightSize)
+                        result = -1;
+                    else if (leftSize > rightSize)
+                        result = +1;
+                }
+
+                break;
             }
-            break;
+        case KDirModel::ModifiedTime: {
+                const QDateTime leftTime = leftItem.time(KFileItem::ModificationTime);
+                const QDateTime rightTime = rightItem.time(KFileItem::ModificationTime);
+                if (leftTime < rightTime)
+                    result = -1;
+                else if (leftTime > rightTime)
+                    result = +1;
+
+                break;
             }
         case KDirModel::Type:
-            // add other sorting modes here
-            // KDirModel::data(index, Qt::DisplayRole) returns the data in index.column()
             result = QString::compare(dirModel->data(left, Qt::DisplayRole).toString(),
                                       dirModel->data(right, Qt::DisplayRole).toString());
             break;
+
+        default:
+            break;
     }
 
     if (result != 0)
@@ -931,12 +959,11 @@ bool FolderModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParen
 
 void FolderModel::createActions()
 {
-    bool m_usedByContainment = true;
-
     KIO::FileUndoManager *manager = KIO::FileUndoManager::self();
 
     QAction *cut = KStandardAction::cut(this, SLOT(cut()), this);
     QAction *copy = KStandardAction::copy(this, SLOT(copy()), this);
+
     QAction *undo = KStandardAction::undo(manager, SLOT(undo()), this);
     undo->setEnabled(manager->undoAvailable());
     undo->setShortcutContext(Qt::WidgetShortcut);
@@ -944,38 +971,24 @@ void FolderModel::createActions()
     connect(manager, SIGNAL(undoTextChanged(QString)), SLOT(undoTextChanged(QString)));
 
     QAction *paste = KStandardAction::paste(this, SLOT(paste()), this);
-
-    QString actionText = KIO::pasteActionText();
-    if (!actionText.isEmpty()) {
-       paste->setText(actionText);
-    } else {
-       paste->setEnabled(false);
-    }
-
     QAction *pasteTo = KStandardAction::paste(this, SLOT(pasteTo()), this);
 
     QAction *reload = new QAction(i18n("&Reload"), this);
     connect(reload, SIGNAL(triggered()), SLOT(refresh()));
 
-    QAction *refresh = new QAction(m_usedByContainment ? i18n("&Refresh Desktop") : i18n("&Refresh View"), this);
-    if (m_usedByContainment) {
-        refresh->setIcon(QIcon("user-desktop"));
-    }
+    QAction *refresh = new QAction(QIcon::fromTheme("view-refresh"), i18n("&Refresh View"), this);
     connect(refresh, SIGNAL(triggered()), SLOT(refresh()));
 
-    QAction *rename = new QAction(QIcon("edit-rename"), i18n("&Rename"), this);
+    QAction *rename = new QAction(QIcon::fromTheme("edit-rename"), i18n("&Rename"), this);
     connect(rename, SIGNAL(triggered()), SIGNAL(requestRename()));
 
-    QAction *trash = new QAction(QIcon("user-trash"), i18n("&Move to Trash"), this);
+    QAction *trash = new QAction(QIcon::fromTheme("user-trash"), i18n("&Move to Trash"), this);
     connect(trash, SIGNAL(triggered()), SLOT(moveSelectedToTrash()));
 
-    QAction *emptyTrash = new QAction(QIcon("trash-empty"), i18n("&Empty Trash Bin"), this);
-    KConfig trashConfig("trashrc", KConfig::SimpleConfig);
-    emptyTrash->setEnabled(!trashConfig.group("Status").readEntry("Empty", true));
+    QAction *emptyTrash = new QAction(QIcon::fromTheme("trash-empty"), i18n("&Empty Trash Bin"), this);
     connect(emptyTrash, SIGNAL(triggered()), SLOT(emptyTrashBin()));
 
-    QAction *del = new QAction(i18n("&Delete"), this);
-    del->setIcon(QIcon("edit-delete"));
+    QAction *del = new QAction(QIcon::fromTheme("edit-delete"), i18n("&Delete"), this);
     connect(del, SIGNAL(triggered()), SLOT(deleteSelected()));
 
     m_actionCollection.addAction("cut", cut);
@@ -988,101 +1001,46 @@ void FolderModel::createActions()
     m_actionCollection.addAction("rename", rename);
     m_actionCollection.addAction("trash", trash);
     m_actionCollection.addAction("del", del);
-    m_actionCollection.addAction("empty_trash", emptyTrash);
+    m_actionCollection.addAction("emptyTrash", emptyTrash);
 
-    m_newMenu = new KNewFileMenu(&m_actionCollection, "new_menu", QApplication::desktop());
+    m_newMenu = new KNewFileMenu(&m_actionCollection, "newMenu", QApplication::desktop());
     m_newMenu->setModal(false);
-
-    connect(m_newMenu->menu(), SIGNAL(aboutToShow()), this, SLOT(aboutToShowCreateNew()));
 }
 
-void FolderModel::openContextMenu()
+QAction* FolderModel::action(const QString &name) const
 {
-    QModelIndexList indexes = m_selectionModel->selectedIndexes();
+    return m_actionCollection.action(name);
+}
 
-    if (!KAuthorized::authorize("action/kdesktop_rmb") || indexes.isEmpty()) {
-        return;
+QObject* FolderModel::newMenu() const
+{
+    return m_newMenu->menu();
+}
+
+void FolderModel::updateActions()
+{
+    if (m_newMenu) {
+        m_newMenu->checkUpToDate();
+        m_newMenu->setPopupFiles(m_dirModel->dirLister()->url());
     }
 
-    KFileItemList items;
-    bool hasRemoteFiles = false;
-    bool isTrashLink = false;
+    QAction *emptyTrash = m_actionCollection.action("emptyTrash");
 
-    foreach (const QModelIndex &index, indexes) {
-        KFileItem item = itemForIndex(index);
-        if (!item.isNull()) {
-            hasRemoteFiles |= item.localPath().isEmpty();
-            items.append(item);
-        }
-    }
-
-    // Check if we're showing the menu for the trash link
-    if (items.count() == 1 && items.at(0).isDesktopFile()) {
-        KDesktopFile file(items.at(0).localPath());
-        if (file.readType() == "Link" && file.readUrl() == "trash:/") {
-            isTrashLink = true;
-        }
-    }
-
-    QAction* pasteTo = m_actionCollection.action("pasteto");
-    if (pasteTo) {
-        if (QAction *paste = m_actionCollection.action("paste")) {
-            updatePasteAction();
-            pasteTo->setEnabled(paste->isEnabled());
-            pasteTo->setText(paste->text());
-        }
-    }
-
-    QList<QAction*> editActions;
-    editActions.append(m_actionCollection.action("rename"));
-
-    KSharedConfig::Ptr globalConfig = KSharedConfig::openConfig("kdeglobals", KConfig::NoGlobals);
-    KConfigGroup cg(globalConfig, "KDE");
-    bool showDeleteCommand = cg.readEntry("ShowDeleteCommand", false);
-
-    // Don't add the "Move to Trash" action if we're showing the menu for the trash link
-    if (!isTrashLink) {
-        if (!hasRemoteFiles) {
-            editActions.append(m_actionCollection.action("trash"));
+    if (emptyTrash) {
+        if (resolvedUrl() == QUrl("trash:/")) {
+            emptyTrash->setVisible(true);
+            KConfig trashConfig("trashrc", KConfig::SimpleConfig);
+            emptyTrash->setEnabled(!trashConfig.group("Status").readEntry("Empty", true));
         } else {
-            showDeleteCommand = true;
+            emptyTrash->setVisible(false);
         }
     }
-    if (showDeleteCommand) {
-        editActions.append(m_actionCollection.action("del"));
-    }
 
-    KParts::BrowserExtension::ActionGroupMap actionGroups;
-    actionGroups.insert("editactions", editActions);
+    QAction *paste = m_actionCollection.action("paste");
 
-    KParts::BrowserExtension::PopupFlags flags = KParts::BrowserExtension::ShowProperties;
-    flags |= KParts::BrowserExtension::ShowUrlOperations;
-
-    // m_newMenu can be NULL here but KonqPopupMenu does handle this.
-    KonqPopupMenu *contextMenu = new KonqPopupMenu(items, m_dirModel->dirLister()->url(), m_actionCollection, m_newMenu,
-                                                   KonqPopupMenu::ShowNewWindow, flags, 0,
-                                                   KBookmarkManager::userBookmarksManager(),
-                                                   actionGroups);
-
-    contextMenu->exec(QCursor::pos());
-    delete contextMenu;
-
-    if (pasteTo) {
-        pasteTo->setEnabled(false);
-    }
-}
-
-void FolderModel::linkHere(const QUrl &sourceUrl)
-{
-    KIO::CopyJob *job = KIO::link(sourceUrl, m_dirModel->dirLister()->url());
-    KIO::FileUndoManager::self()->recordCopyJob(job);
-}
-
-
-void FolderModel::updatePasteAction()
-{
-    if (QAction *paste = m_actionCollection.action("paste")) {
+    if (paste) {
         const QString pasteText = KIO::pasteActionText();
+
         if (pasteText.isEmpty()) {
             paste->setText(i18n("&Paste"));
             paste->setEnabled(false);
@@ -1090,15 +1048,106 @@ void FolderModel::updatePasteAction()
             paste->setText(pasteText);
             paste->setEnabled(true);
         }
+
+        QAction* pasteTo = m_actionCollection.action("pasteto");
+
+        if (pasteTo) {
+            pasteTo->setEnabled(paste->isEnabled());
+            pasteTo->setText(paste->text());
+        }
     }
 }
 
-void FolderModel::aboutToShowCreateNew()
+void FolderModel::openContextMenu()
 {
-    if (m_newMenu) {
-        m_newMenu->checkUpToDate();
-        m_newMenu->setPopupFiles(m_dirModel->dirLister()->url());
+    QModelIndexList indexes = m_selectionModel->selectedIndexes();
+
+    if (m_usedByContainment && !KAuthorized::authorize("action/kdesktop_rmb")) {
+        return;
     }
+
+    updateActions();
+
+    QMenu *menu = 0;
+
+    if (indexes.isEmpty()) {
+        menu = new QMenu();
+        menu->addAction(m_actionCollection.action("newMenu"));
+        menu->addSeparator();
+        menu->addAction(m_actionCollection.action("paste"));
+        menu->addAction(m_actionCollection.action("undo"));
+        menu->addAction(m_actionCollection.action("refresh"));
+        menu->addAction(m_actionCollection.action("emptyTrash"));
+        menu->addSeparator();
+
+        if (!m_fileItemActions) {
+            m_fileItemActions = new KFileItemActions(this);
+        }
+
+        KFileItemListProperties itemList(KFileItemList() << m_dirModel->dirLister()->rootItem());
+        m_fileItemActions->setItemListProperties(itemList);
+
+        menu->addAction(m_fileItemActions->preferredOpenWithAction(QString()));
+    } else {
+        KFileItemList items;
+        bool hasRemoteFiles = false;
+        bool isTrashLink = false;
+
+        foreach (const QModelIndex &index, indexes) {
+            KFileItem item = itemForIndex(index);
+            if (!item.isNull()) {
+                hasRemoteFiles |= item.localPath().isEmpty();
+                items.append(item);
+            }
+        }
+
+        // Check if we're showing the menu for the trash link
+        if (items.count() == 1 && items.at(0).isDesktopFile()) {
+            KDesktopFile file(items.at(0).localPath());
+            if (file.readType() == "Link" && file.readUrl() == "trash:/") {
+                isTrashLink = true;
+            }
+        }
+
+        QList<QAction*> editActions;
+        editActions.append(m_actionCollection.action("rename"));
+
+        KSharedConfig::Ptr globalConfig = KSharedConfig::openConfig("kdeglobals", KConfig::NoGlobals);
+        KConfigGroup cg(globalConfig, "KDE");
+        bool showDeleteCommand = cg.readEntry("ShowDeleteCommand", false);
+
+        // Don't add the "Move to Trash" action if we're showing the menu for the trash link
+        if (!isTrashLink) {
+            if (!hasRemoteFiles) {
+                editActions.append(m_actionCollection.action("trash"));
+            } else {
+                showDeleteCommand = true;
+            }
+        }
+        if (showDeleteCommand) {
+            editActions.append(m_actionCollection.action("del"));
+        }
+
+        KParts::BrowserExtension::ActionGroupMap actionGroups;
+        actionGroups.insert("editactions", editActions);
+
+        KParts::BrowserExtension::PopupFlags flags = KParts::BrowserExtension::ShowProperties;
+        flags |= KParts::BrowserExtension::ShowUrlOperations;
+
+        menu = new KonqPopupMenu(items, m_dirModel->dirLister()->url(), m_actionCollection, m_newMenu,
+                                 KonqPopupMenu::ShowNewWindow, flags, 0,
+                                 KBookmarkManager::userBookmarksManager(),
+                                 actionGroups);
+    }
+
+    menu->exec(QCursor::pos());
+    delete menu;
+}
+
+void FolderModel::linkHere(const QUrl &sourceUrl)
+{
+    KIO::CopyJob *job = KIO::link(sourceUrl, m_dirModel->dirLister()->url());
+    KIO::FileUndoManager::self()->recordCopyJob(job);
 }
 
 QList<QUrl> FolderModel::selectedUrls(bool forTrash) const
@@ -1133,7 +1182,7 @@ void FolderModel::copy()
 void FolderModel::cut()
 {
     QMimeData *mimeData = QSortFilterProxyModel::mimeData(m_selectionModel->selectedIndexes());
-    KonqMimeData::addIsCutSelection(mimeData, true);
+    KIO::setClipboardDataCut(mimeData, true);
     QApplication::clipboard()->setMimeData(mimeData);
 }
 
@@ -1156,17 +1205,32 @@ void FolderModel::refresh()
 
 void FolderModel::moveSelectedToTrash()
 {
-    KonqOperations::del(QApplication::desktop(), KonqOperations::TRASH, selectedUrls(true));
+    const QList<QUrl> urls = selectedUrls(true);
+    KIO::JobUiDelegate uiDelegate;
+    if (uiDelegate.askDeleteConfirmation(urls, KIO::JobUiDelegate::Trash, KIO::JobUiDelegate::DefaultConfirmation)) {
+        KIO::Job* job = KIO::trash(urls);
+        job->ui()->setAutoErrorHandlingEnabled(true);
+    }
 }
 
 void FolderModel::deleteSelected()
 {
-    KonqOperations::del(QApplication::desktop(), KonqOperations::DEL, selectedUrls(false));
+    const QList<QUrl> urls = selectedUrls(false);
+    KIO::JobUiDelegate uiDelegate;
+    if (uiDelegate.askDeleteConfirmation(urls, KIO::JobUiDelegate::Delete, KIO::JobUiDelegate::DefaultConfirmation)) {
+        KIO::Job* job = KIO::del(urls);
+        job->ui()->setAutoErrorHandlingEnabled(true);
+    }
 }
 
 void FolderModel::emptyTrashBin()
 {
-    KonqOperations::emptyTrash(QApplication::desktop());
+    KIO::JobUiDelegate uiDelegate;
+    uiDelegate.setWindow(QApplication::desktop());
+    if (uiDelegate.askDeleteConfirmation(QList<QUrl>(), KIO::JobUiDelegate::EmptyTrash, KIO::JobUiDelegate::DefaultConfirmation)) {
+        KIO::Job* job = KIO::emptyTrash();
+        job->ui()->setAutoErrorHandlingEnabled(true);
+    }
 }
 
 void FolderModel::undoTextChanged(const QString &text)
