@@ -35,6 +35,8 @@
 #include <KFilePreviewGenerator>
 #include <KDirLister>
 
+#include <KNewFileMenu>
+
 class QDrag;
 class QItemSelectionModel;
 class QQuickItem;
@@ -42,6 +44,7 @@ class QQuickItem;
 class KActionCollection;
 class KDirModel;
 class KFileItem;
+class KFileItemActions;
 class KNewFileMenu;
 
 class DirLister : public KDirLister
@@ -64,6 +67,7 @@ class FolderModel : public QSortFilterProxyModel
     Q_OBJECT
 
     Q_PROPERTY(QString url READ url WRITE setUrl NOTIFY urlChanged)
+    Q_PROPERTY(QUrl resolvedUrl READ resolvedUrl NOTIFY resolvedUrlChanged)
     Q_PROPERTY(QString errorString READ errorString NOTIFY errorStringChanged)
     Q_PROPERTY(bool usedByContainment READ usedByContainment WRITE setUsedByContainment NOTIFY usedByContainmentChanged);
     Q_PROPERTY(bool locked READ locked WRITE setLocked NOTIFY lockedChanged)
@@ -77,6 +81,7 @@ class FolderModel : public QSortFilterProxyModel
     Q_PROPERTY(int filterMode READ filterMode WRITE setFilterMode NOTIFY filterModeChanged)
     Q_PROPERTY(QString filterPattern READ filterPattern WRITE setFilterPattern NOTIFY filterPatternChanged)
     Q_PROPERTY(QStringList filterMimeTypes READ filterMimeTypes WRITE setFilterMimeTypes NOTIFY filterMimeTypesChanged)
+    Q_PROPERTY(QObject* newMenu READ newMenu CONSTANT)
 
     public:
         enum DataRole {
@@ -99,10 +104,13 @@ class FolderModel : public QSortFilterProxyModel
         ~FolderModel();
 
         QHash<int, QByteArray> roleNames() const;
+        static QHash<int, QByteArray> staticRoleNames();
 
         QString url() const;
         void setUrl(const QString &url);
 
+        QUrl resolvedUrl() const;
+
         QString errorString() const;
 
         bool usedByContainment() const;
@@ -148,8 +156,8 @@ class FolderModel : public QSortFilterProxyModel
         Q_INVOKABLE bool isSelected(int row);
         Q_INVOKABLE void setSelected(int row);
         Q_INVOKABLE void toggleSelected(int row);
-        Q_INVOKABLE void setRangeSelected(int startRow, int endRow);
-        Q_INVOKABLE void updateSelection(const QVariantList &rows, bool replace);
+        Q_INVOKABLE void setRangeSelected(int anchor, int to);
+        Q_INVOKABLE void updateSelection(const QVariantList &rows, bool toggle);
         Q_INVOKABLE void clearSelection();
         Q_INVOKABLE void pinSelection();
         Q_INVOKABLE void unpinSelection();
@@ -163,6 +171,9 @@ class FolderModel : public QSortFilterProxyModel
 
         Q_INVOKABLE bool isBlank(int row) const;
 
+        Q_INVOKABLE QAction* action(const QString& name) const;
+        QObject* newMenu() const;
+        Q_INVOKABLE void updateActions();
         Q_INVOKABLE void openContextMenu();
 
         Q_INVOKABLE void linkHere(const QUrl &sourceUrl);
@@ -175,6 +186,7 @@ class FolderModel : public QSortFilterProxyModel
 
     Q_SIGNALS:
         void urlChanged() const;
+        void resolvedUrlChanged() const;
         void errorStringChanged() const;
         void usedByContainmentChanged() const;
         void lockedChanged() const;
@@ -199,7 +211,6 @@ class FolderModel : public QSortFilterProxyModel
     private Q_SLOTS:
         void dirListFailed(const QString &error);
         void selectionChanged(QItemSelection selected, QItemSelection deselected);
-        void aboutToShowCreateNew();
         void copy();
         void cut();
         void paste();
@@ -235,6 +246,7 @@ class FolderModel : public QSortFilterProxyModel
         QPointer<KAbstractViewAdapter> m_viewAdapter;
         KActionCollection m_actionCollection;
         KNewFileMenu *m_newMenu;
+        KFileItemActions *m_fileItemActions;
         QString m_errorString;
         bool m_usedByContainment;
         bool m_locked;
