@@ -23,7 +23,6 @@
 
 #include "konq_operations.h"
 #include "konq_dndpopupmenuplugin.h"
-#include "konqmimedata.h"
 
 #include <ktoolinvocation.h>
 #include <kautomount.h>
@@ -145,7 +144,7 @@ KonqOperations *KonqOperations::doPasteV2(QWidget *parent, const KUrl &destUrl,
 {
     QClipboard *clipboard = QApplication::clipboard();
     const QMimeData *data = clipboard->mimeData();
-    const bool move = KonqMimeData::decodeIsCutSelection(data);
+    const bool move = KIO::isClipboardDataCut(data);
 
     KIO::Job *job = KIO::pasteClipboard(destUrl, parent, move);
     if (job) {
@@ -795,28 +794,11 @@ void KonqOperations::setOperation( KIO::Job * job, Operation method, const KUrl
         KJobWidgets::setWindow(job, parentWidget());
         connect( job, &KIO::Job::result,
                  this, &KonqOperations::slotResult );
-#if 0
-        KIO::CopyJob *copyJob = dynamic_cast<KIO::CopyJob*>(job);
-        KonqIconViewWidget *iconView = dynamic_cast<KonqIconViewWidget*>(parent());
-        if (copyJob && iconView)
-        {
-            connect(copyJob, SIGNAL(aboutToCreate(KIO::Job*,QList<KIO::CopyInfo>)),
-                 this, SLOT(slotAboutToCreate(KIO::Job*,QList<KIO::CopyInfo>)));
-            // TODO move this connect into the iconview!
-            connect(this, SIGNAL(aboutToCreate(QPoint,QList<KIO::CopyInfo>)),
-                 iconView, SLOT(slotAboutToCreate(QPoint,QList<KIO::CopyInfo>)));
-        }
-#endif
     }
     else // for link
         slotResult( 0L );
 }
 
-void KonqOperations::slotAboutToCreate(KIO::Job *, const QList<KIO::CopyInfo> &files)
-{
-    emit aboutToCreate( m_info ? m_info->mousePos : m_pasteInfo ? m_pasteInfo->mousePos : QPoint(), files);
-}
-
 void KonqOperations::statUrl( const KUrl & url, const QObject *receiver, const char *member, QWidget* parent )
 {
     KonqOperations * op = new KonqOperations( parent );
@@ -1034,8 +1016,17 @@ QPair<bool, QString> KonqOperations::pasteInfo(const KUrl& targetUrl)
     QClipboard* clipboard = QApplication::clipboard();
     const QMimeData* mimeData = clipboard->mimeData();
 
-    const bool canPasteData = KIO::canPasteMimeData(mimeData);
-    KUrl::List urls = KUrl::List::fromMimeData(mimeData);
+    bool canPasteData = false;
+    KUrl::List urls;
+
+    // mimeData can be 0 according to https://bugs.kde.org/show_bug.cgi?id=335053
+    if (mimeData) {
+        canPasteData = KIO::canPasteMimeData(mimeData);
+        urls = KUrl::List::fromMimeData(mimeData);
+    } else {
+        kWarning(1203) << "QApplication::clipboard()->mimeData() is 0!";
+    }
+
     if (!urls.isEmpty() || canPasteData) {
         // disable the paste action if no writing is supported
         KFileItem item(KFileItem::Unknown, KFileItem::Unknown, targetUrl);
@@ -1058,5 +1049,3 @@ QPair<bool, QString> KonqOperations::pasteInfo(const KUrl& targetUrl)
 
     return ret;
 }
-
-#include "konq_operations.moc"
