@@ -69,8 +69,8 @@ KDEDConfig::KDEDConfig(QWidget* parent, const QVariantList &) :
 	KCModule( parent )
 {
 	KAboutData *about =
-		new KAboutData( I18N_NOOP( "kcmkded" ), 0, i18n( "KDE Service Manager" ),
-				QString(), KAboutLicense::GPL,
+        new KAboutData( I18N_NOOP( "kcmkded" ), i18n( "KDE Service Manager" ),
+                QStringLiteral("1.0"), QString(), KAboutLicense::GPL,
 				i18n( "(c) 2002 Daniel Molkentin" ) );
 	about->addAuthor(i18n("Daniel Molkentin"), QString(),"molkentin@kde.org");
 	setAboutData( about );
