@@ -373,6 +373,7 @@ static void createGtkrc( bool exportColors, const QPalette& cg, bool exportGtkTh
         t << "style \"MenuItem\"" << endl;
         t << "{" << endl;
         t << "  bg[PRELIGHT] = " << color( cg.color(QPalette::Highlight) ) << endl;
+        t << "  fg[PRELIGHT] = " << color( cg.color(QPalette::HighlightedText) ) << endl;
         t << "}" << endl;
         t << endl;
         t << "class \"*MenuItem\" style \"MenuItem\"" << endl;
@@ -407,8 +408,8 @@ void runRdb( uint flags )
   KConfigGroup generalCfgGroup(kglobalcfg, "General");
 
   QString gtkTheme;
-  if (generalCfgGroup.hasKey("widgetStyle"))
-    gtkTheme = generalCfgGroup.readEntry("widgetStyle");
+  if (kglobals.hasKey("widgetStyle"))
+    gtkTheme = kglobals.readEntry("widgetStyle");
   else
     gtkTheme = "oxygen";
 
@@ -429,7 +430,7 @@ void runRdb( uint flags )
     addColorDef(preproc, "SELECT_BACKGROUND"  , newPal.color( QPalette::Active, QPalette::Highlight));
     addColorDef(preproc, "SELECT_FOREGROUND"  , newPal.color( QPalette::Active, QPalette::HighlightedText));
     addColorDef(preproc, "WINDOW_BACKGROUND"  , newPal.color( QPalette::Active, QPalette::Base ) );
-    addColorDef(preproc, "WINDOW_FOREGROUND"  , newPal.color( QPalette::Active, QPalette::Foreground ) );
+    addColorDef(preproc, "WINDOW_FOREGROUND"  , newPal.color( QPalette::Active, QPalette::Text ) );
     addColorDef(preproc, "INACTIVE_BACKGROUND", KGlobalSettings::inactiveTitleColor());
     addColorDef(preproc, "INACTIVE_FOREGROUND", KGlobalSettings::inactiveTitleColor());
     addColorDef(preproc, "ACTIVE_BACKGROUND"  , KGlobalSettings::activeTitleColor());
@@ -683,7 +684,7 @@ void runRdb( uint flags )
   kglobals4.writeEntry("ShowIconsOnPushButtons", kglobals.readEntry("ShowIconsOnPushButtons", true));
   kglobals4.writeEntry("contrast", kglobals.readEntry("contrast", 4));
   //FIXME: this should somehow check if the kde4 version of the style is installed
-  kde4generalGroup.writeEntry("widgetStyle", kglobals.readEntry("widgetStyle", "oxygen"));
+  kde4generalGroup.writeEntry("widgetStyle", kglobals.readEntry("widgetStyle", "breeze"));
 
   //toolbar style
   KConfigGroup toolbars4(&kde4config, "Toolbar style");
